@@ -294,8 +294,14 @@ class _AsyncExpander:
         self.database = database
 
     async def __call__(self):
-        """Return the whole transaction as a python list"""
-        await self.database.command.transaction(self.transaction)
+        """Execute transaction
+
+        Returns
+        -------
+        dict
+            Transaction status object
+        """
+        return await self.database.command.transaction(self.transaction)
 
     def __getattr__(self, name):
         """Get a functor for adding named operators to the transaction, using a template again
